LOICA: Logical Operators for INtegrated Cell Algorithms
=======================================

This Python package provides a set of tools for the modeling, design and characterization of genetic networks.

